@@ -103,7 +103,7 @@ final class CodeCoverage
     public function getReport(): Directory
     {
         if ($this->cachedReport === null) {
-            $this->cachedReport = (new Builder($this->analyser()))->build($this);
+            $this->cachedReport = new Builder($this->analyser())->build($this);
         }
 
         return $this->cachedReport;
@@ -411,6 +411,7 @@ final class CodeCoverage
      */
     public function driverIsPcov(): bool
     {
+        /** @phpstan-ignore isset.initializedProperty */
         return isset($this->driver) && $this->driver->isPcov();
     }
 
@@ -419,6 +420,7 @@ final class CodeCoverage
      */
     public function driverIsXdebug(): bool
     {
+        /** @phpstan-ignore isset.initializedProperty */
         return isset($this->driver) && $this->driver->isXdebug();
     }
 
