@@ -41,16 +41,17 @@ final readonly class Facade
 
     public function process(CodeCoverage $coverage, string $target): void
     {
-        $target = $this->directory($target);
-        $report = $coverage->getReport();
-        $date   = date('D M j G:i:s T Y');
+        $target            = $this->directory($target);
+        $report            = $coverage->getReport();
+        $date              = date('D M j G:i:s T Y');
+        $hasBranchCoverage = $coverage->getData(true)->functionCoverage() !== [];
 
         $dashboard = new Dashboard(
             $this->templatePath,
             $this->generator,
             $date,
             $this->thresholds,
-            $coverage->collectsBranchAndPathCoverage(),
+            $hasBranchCoverage,
         );
 
         $directory = new Directory(
@@ -58,7 +59,7 @@ final readonly class Facade
             $this->generator,
             $date,
             $this->thresholds,
-            $coverage->collectsBranchAndPathCoverage(),
+            $hasBranchCoverage,
         );
 
         $file = new File(
@@ -66,7 +67,7 @@ final readonly class Facade
             $this->generator,
             $date,
             $this->thresholds,
-            $coverage->collectsBranchAndPathCoverage(),
+            $hasBranchCoverage,
         );
 
         $directory->render($report, $target . 'index.html');
