@@ -14,10 +14,10 @@ use XMLWriter;
 /**
  * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
  */
-final class Coverage
+final readonly class Coverage
 {
-    private readonly XMLWriter $xmlWriter;
-    private readonly string $line;
+    private XMLWriter $xmlWriter;
+    private string $line;
 
     public function __construct(
         XMLWriter $xmlWriter,
