@@ -8,3 +8,9 @@ class MyDnf
         return $entity;                     // +1
     }
 }
+
+// Const in traits
+trait MyConstInTrait
+{
+    public const MY_TRAIT_CONST = 1;
+}
\ No newline at end of file
